The LAMBADA dataset evaluates the capabilities of computational models for text
understanding by means of a word prediction task. LAMBADA is a collection of
narrative passages sharing the characteristic that human subjects are able to
guess their last word if they are exposed to the whole passage, but not if they
only see the last sentence preceding the target word
